hive-vectorcraft.port

Boundary port. A future cljw or native transport will implement the same operation. No transport is installed in wave 1.

Boundary port. A future cljw or native transport will implement the same operation. No transport is installed in wave 1.
raw docstring

ControlTransportcljprotocol

send-requestclj

(send-request transport request)

Send one validated control request and return a response value.

Send one validated control request and return a response value.
source

cljdoc builds & hosts documentation for Clojure/Script libraries