hive-vectorcraft.schema

JVM value-object schemas for the portable vocabulary and boundary envelopes.

JVM value-object schemas for the portable vocabulary and boundary envelopes.
raw docstring

Catalogclj

source

CatalogEntryclj

source

envelopeclj

(envelope value)
source

ErrorValueclj

source

Requestclj

source

SocketConfigclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries