hive-vectorcraft.transport.socket

JVM loopback client for the app's --control channel: one JSON line out, one JSON line back.

JVM loopback client for the app's --control channel: one JSON line out, one JSON line back.
raw docstring

default-configclj

Loopback host, the port the app was started with, and per-request connect and read bounds.

Loopback host, the port the app was started with, and per-request connect and read bounds.
sourceraw docstring

socket-transportclj

(socket-transport config)

Build a transport for an app listening on --control <port>; config overrides default-config.

Build a transport for an app listening on --control <port>; config overrides default-config.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries