Boundary port. A future cljw or native transport will implement the same operation. No transport is installed in wave 1.
Boundary port. A future cljw or native transport will implement the same operation. No transport is installed in wave 1.
(send-request transport request)Send one validated control request and return a response value.
Send one validated control request and return a response value.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |