JVM loopback client for the app's --control channel: one JSON line out, one JSON line back.
JVM loopback client for the app's --control channel: one JSON line out, one JSON line back.
Loopback host, the port the app was started with, and per-request connect and read bounds.
Loopback host, the port the app was started with, and per-request connect and read bounds.
(socket-transport config)Build a transport for an app listening on --control <port>; config overrides default-config.
Build a transport for an app listening on --control <port>; config overrides default-config.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |